@@ -9,7 +9,9 @@ from kiraak.main import main
 
 
 @click.command()
-@click.argument("json_file", type=click.Path(exists=True, dir_okay=False), required=False)
+@click.argument(
+    "json_file", type=click.Path(exists=True, dir_okay=False), required=False
+)
 @click.option("-c", "--clear", is_flag=True)
 @click.option("-g", "--get-catalog", is_flag=True)
 def cli(json_file: str, clear, get_catalog) -> None:
@@ -21,6 +23,7 @@ def cli(json_file: str, clear, get_catalog) -> None:
 
     if get_catalog:
         from kiraak.get_catalog import download_catalog
+
         download_catalog()
         sys.exit()
 
